============================
Documentation for jwedb
============================

``jwedb`` provides a programmatic python interface to the JWST DMS Engineering Database hosted at the MAST archive. It uses services provided by the ``astroquery.mast`` module.

To take advantage of all ``jwedb`` funcionalities, the user has to submit a valid MAST token.

.. toctree::
  :maxdepth: 3
  :caption: Contents:

  jwedb <jwedb/index.rst>

.. note:: ``jwedb`` is a spin-off the ``jwql`` project.


* :ref:`genindex`
* :ref:`modindex`
